@@ -24,7 +24,7 @@ def _setup_protocols(root):
             factory_class = _import(factory_class_import)
             reactor.listenWith(port_class, factory=factory_class(), resource=root, childName=child_path)
             logger.info('%s protocol active' % config_key)
-    
+
 def _setup_static(root, config):
     from twisted.web import static
     for key, val in config['[static]'].items():
@@ -32,13 +32,24 @@ def _setup_static(root, config):
             key = ''
         if root.getStaticEntity(key):
             logger.error("cannot mount static directory with reserved name %s" % key)
-            sys.exit(-1)
+            sys.exit(1)
         root.putChild(key, static.File(val))
 
 def main():
+    try:
+        import twisted
+    except ImportError:
+        print "Orbited requires Twisted, which is not installed. See http://twistedmatrix.com/trac/ for installation instructions."
+        sys.exit(1)
+    import platform
+    if platform.system() == "Windows":
+        try:
+            import win32api
+        except ImportError:
+            print "Orbited for Windows requires the Python for Windows Extensions, which are not installed. See http://python.net/crew/mhammond/win32/ for installation instructions."
+            sys.exit(1)
     from optparse import OptionParser
     parser = OptionParser()
-    # TODO: this should be in start.py, not here.
     parser.add_option(
         "-c",
         "--config",
@@ -62,15 +73,34 @@ def main():
         default=False,
         help="run Orbited with a profiler"
     )
-    
-    (options, args) = parser.parse_args(sys.argv)    
-    
+    parser.add_option(
+        "-q",
+        "--quickstart",
+        dest="quickstart",
+        action="store_true",
+        default=False,
+        help="run Orbited on port 8000 and MorbidQ on port 61613"
+    )
+
+    (options, args) = parser.parse_args()
+
+    if args:
+        print 'the "orbited" command does not accept positional arguments. type "orbited -h" for options.'
+        sys.exit(1)
+
     if options.version:
         print "Orbited version: %s" % (version,)
         sys.exit(0)
-    # load configuration from configuration file and from command
-    # line arguments.
-    config.setup(options=options)
+
+    if options.quickstart:
+        config.map['[listen]'].append('http://:8000')
+        config.map['[listen]'].append('stomp://:61613')
+        config.map['[access]'][('localhost',61613)] = ['*']
+        print "Quickstarting Orbited"
+    else:
+        # load configuration from configuration
+        # file and from command line arguments.
+        config.setup(options=options)
 
     logging.setup(config.map)
 
@@ -85,6 +115,15 @@ def main():
         install()
         logger.info('using %s reactor' % reactor_name)
 
+    ############
+    # This crude garbage corrects a bug in twisted
+    #   Orbited ticket: http://orbited.org/ticket/111
+    #   Twisted ticket: http://twistedmatrix.com/trac/ticket/2447
+    import twisted.web.http
+    twisted.web.http.HTTPChannel.setTimeout = lambda self, arg: None
+    twisted.web.http.HTTPChannel.resetTimeout = lambda self: None
+    ############
+
     from twisted.internet import reactor
     from twisted.web import resource
     from twisted.web import server
@@ -125,13 +164,13 @@ def main():
                     group = gr.gr_name
             except Exception, e:
                 logger.error('Aborting; Unknown user or group: %s' % e)
-                sys.exit(-1)
+                sys.exit(1)
             logger.info('switching to user %s (uid=%d) and group %s (gid=%d)' % (user, uid, group, gid))
             os.setgid(gid)
             os.setuid(uid)
         else:
             logger.error('Aborting; You must define a user (and optionally a group) in the configuration file.')
-            sys.exit(-1)
+            sys.exit(1)
 
     if options.profile:
         import hotshot
@@ -179,7 +218,7 @@ def start_listening(site, config, logger):
                 raise
             except:
                 logger.error("Error opening key or crt file: %s, %s" % (key, crt))
-                sys.exit(-1)
+                sys.exit(1)
             logger.info('Listening https@%s (%s, %s)' % (url.port, key, crt))
             reactor.listenSSL(url.port, site, ssl_context, interface=hostname)
         elif url.scheme in test_servers:
@@ -191,7 +230,7 @@ def start_listening(site, config, logger):
                 config['globalVars']['monitoring'] = url.port
         else:
             logger.error("Invalid Listen URI: %s" % addr)
-            sys.exit(-1)
+            sys.exit(1)
 
 
 if __name__ == "__main__":
