@@ -5,48 +5,96 @@ ROSTER = ["<iq from='","' type='get'><query xmlns='jabber:iq:roster'/></iq><pres
 MSG = ["<message from='","' to='","' xml:lang='en' type='chat'><body>","</body></message>"];
 PRESENCE = ["<presence from='","' to='","' type='","'/>"];
 
-XMLStreamParser = function() {
+XMLReader = function() {
     var self = this;
-    var buffer = ""
-    var parser=new DOMParser();
-
-    self.onread = function(node) { }
-
-    self.receive = function(data) {
-        buffer += data
-        parseBuffer()
-    }
-
-    var parseBuffer = function() {
-        while (true) {
-            var tagOpenStartIndex = buffer.indexOf('<')
-            var tagOpenEndIndex = buffer.indexOf('>', tagOpenStartIndex)
-            if (tagOpenEndIndex == -1) {
-                return
+    var parse = null;
+    var cb = null;
+    var name = null;
+    var buff = "";
+    var checked = 0;
+    var get_parser = function() {
+        var parser = null;
+        if (window.DOMParser) {
+            parser = new DOMParser();
+            parse = function(s) {
+                return parser.parseFromString(s, "text/xml");
             }
-            var endTagNameIndex = Math.min(buffer.indexOf(' ', tagOpenStartIndex), tagOpenEndIndex)
-            
-            var tagName = buffer.slice(tagOpenStartIndex+1, endTagNameIndex)
-            var nodePayload = ""
-            // Allows detection of self contained tags like "<tag />"
-            // TODO: don't make whitespace count. allow "<tag /  >"
-            //       (is that valid xml?)
-            if (buffer[tagOpenEndIndex-1] == '/') {
-                nodePayload = buffer.slice(tagOpenStartIndex, tagOpenEndIndex+1)
+        }
+        else if (window.ActiveXObject) {
+            parse = function(s) {
+                parser = new ActiveXObject("Microsoft.XMLDOM");
+                parser.async = "false";
+                parser.loadXML(s);
+                return parser;
             }
-            else {
-                var endTag = '</' + tagName + '>'
-                var endTagIndex = buffer.indexOf(endTag)
-                if (endTagIndex== -1) {
-                    return
-                }
-                var nodePayload= buffer.slice(tagOpenStartIndex, endTagIndex + endTag.length)
-            }
-            var rootNode =parser.parseFromString(nodePayload,"text/xml");
-            buffer = buffer.slice(tagOpenStartIndex + nodePayload.length)
-            self.onread(rootNode.childNodes[0]);
+        }
+        else {
+            alert("can't find suitable XML parser! what kind of crazy browser are you using?");
         }
     }
+    var separate_events = function() {
+        if (!name) {
+            if (!buff) {
+                return;
+            }
+            if (buff.slice(0,1) != "<") {
+                checked = 0;
+                buff = buff.slice(1);
+                return separate_events();
+            }
+            close_index = buff.indexOf(">");
+            if (close_index == -1) {
+                return;
+            }
+            if (buff.charAt(close_index-1) == "/") {
+                var frame = parse(buff.slice(0,close_index+1)).firstChild;
+                buff = buff.slice(close_index+1);
+                checked = 0;
+                cb(frame);
+                return separate_events();
+            }
+            name = buff.slice(1,close_index);
+            var s = name.indexOf(" ");
+            if (s != -1) {
+                name = name.slice(0,s);
+            }
+            checked = close_index+1;
+        }
+        var i = buff.indexOf(">", checked);
+        while (i != -1) {
+            if (buff.slice(i-2-name.length,i+1) == "</"+name+">") {
+                var frame = parse(buff.slice(0, i+1)).firstChild;
+                if (frame.nodeName == "parsererror") {
+                    var frame = parse(buff.slice(0, i+1).replace("&","&amp;")).firstChild;
+                }
+                buff = buff.slice(i+1);
+                checked = 0;
+                name = null;
+                cb(frame);
+                return separate_events();
+            }
+            else {
+                checked = i+1;
+                i = buff.indexOf(">", checked);
+            }
+        }
+    }
+    self.text = function(node) {
+        // Vlad Shevchenko's IE patch
+        var t = node.text;
+        if (t == undefined) {
+            t = node.textContent;
+        }
+        return t;
+    }
+    self.set_cb = function(func) {
+        cb = func;
+    }
+    self.read = function(data) {
+        buff += data;
+        separate_events();
+    }
+    get_parser();
 }
 
 XMPPClient = function() {
@@ -60,10 +108,11 @@ XMPPClient = function() {
     var full_jid = null;
     var success = null;
     var failure = null;
-    var parser = new XMLStreamParser();
+    var parser = new XMLReader();
     self.onPresence = function(ntype, from) {}
     self.onMessage = function(jid, username, text) {}
     self.onSocketConnect = function() {}
+    self.onUnknownNode = function(node) {}
     self.sendSubscribed = function(jid, me_return) {
         self.send(construct(PRESENCE, [me_return, jid, "subscribed"]));
     }
@@ -73,13 +122,13 @@ XMPPClient = function() {
         reconnect();
     }
     self.msg = function(to, content) {
-        self.send(construct(MSG, [user, to, content]));
+        self.send(construct(MSG, [full_jid, to, content]));
     }
     self.unsubscribe = function(buddy) {
-        self.send(construct(PRESENCE, [bare_jid, buddy.slice(0, buddy.indexOf('/')), "unsubscribe"]));
+        self.send(construct(PRESENCE, [full_jid, buddy.slice(0, buddy.indexOf('/')), "unsubscribe"]));
     }
     self.subscribe = function(buddy) {
-        self.send(construct(PRESENCE, [bare_jid, buddy, "subscribe"]));
+        self.send(construct(PRESENCE, [full_jid, buddy, "subscribe"]));
     }
     self.send = function(s) {
         /////////
@@ -115,6 +164,22 @@ XMPPClient = function() {
         domain = d;
         self.send(construct(CONNECT, [domain]));
     }
+    //partial support for MUC
+    self.join_room = function(room, status, status_msg) {
+        room_id = room;
+        room_jid = room_id + '/' + user;
+        self.send(EXT_PRESENCE[0] + full_jid + EXT_PRESENCE[1] + room_jid + EXT_PRESENCE[3] + status + EXT_PRESENCE[4] + status_msg + EXT_PRESENCE[5]);
+    }
+    self.leave_room = function() {
+        self.send(construct(PRESENCE, [full_jid, room_jid, 'unavailable']));
+    }
+    self.groupchat_msg = function(content) {
+        self.send(construct(GROUPCHAT_MSG, [full_jid, room_id, content]));
+    }
+    self.set_presence = function(status, status_msg) {
+        self.send(EXT_PRESENCE[0] + full_jid + EXT_PRESENCE[1] + room_jid + EXT_PRESENCE[3] + status + EXT_PRESENCE[4] + status_msg + EXT_PRESENCE[5]);
+    }
+    // end support for MUC
     var construct = function(list1, list2) {
         var return_str = "";
         for (var i = 0; i < list2.length; i++) {
@@ -127,36 +192,50 @@ XMPPClient = function() {
         conn.onread = setDomain;
         conn.onopen = self.onSocketConnect;
         conn.onclose = close;
-        parser.onread = nodeReceived;
+        parser.set_cb(nodeReceived);
         conn.open(host, port, true);
 //        console.log("connection opened");
     }
     var nodeReceived = function(node) {
-//        console.log("received node: "+node.nodeName);
-//        var a = node.attributes;
-//        for (var i = 0; i < a.length; i++) {
-//            console.log("   " + a[i].localName + ": " + a[i].value);
-//        }
+        if (!node) { // for IE - necessary?
+            return;
+        }
         if (node.nodeName == "message") {
             var from = node.getAttribute("from");
             var c = node.childNodes;
+            var body = null
+            var stamp = null;
             for (var i = 0; i < c.length; i++) {
-                if (c[i].nodeName == "body") {
-                    self.onMessage(from, from, c[i].textContent);
-                }
+                if (c[i].nodeName == "body")
+                    body = parser.text(c[i]);
+                else if (c[i].nodeName == "delay" || (c[i].nodeName == "x" && c[i].getAttribute("xmlns") == "jabber:x:delay"))
+                    stamp = c[i].getAttribute("stamp");
             }
+            if (body)
+                self.onMessage(from, from, body, stamp);
         }
         else if (node.nodeName == "presence") {
             var ntype = node.getAttribute("type");
             var from = node.getAttribute("from");
             var to = node.getAttribute("to");
-            self.onPresence(ntype, from, to);
+            var show = null;
+            var status = null;
+            var c = node.childNodes;
+            for (var i = 0; i < c.length; i++) {
+                if (c[i].nodeName == "show")
+                    show = parser.text(c[i]);
+                else if (c[i].nodeName == "status")
+                    status = parser.text(c[i]);
+            }
+            self.onPresence(ntype, from, to, show, status);
         }
+        else
+            self.onUnknownNode(node);
     }
     var read = function(evt) {
         var s = Orbited.utf8.decode(evt);
 //        console.log('received: '+s);
-        parser.receive(s);
+        parser.read(s);
     }
     var setDomain = function(evt) {
         var s = Orbited.utf8.decode(evt);
@@ -187,7 +266,7 @@ XMPPClient = function() {
         }
         else {
             conn.onread = read;
-            self.send(construct(ROSTER, [bare_jid]));
+            self.send(construct(ROSTER, [full_jid]));
             if (success) {success();}
         }
     }
